@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def createFull(vmanage):
     """
     Create full topology
@@ -13,8 +10,8 @@ def createFull(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/topology"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/topology"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def createDevice(vmanage, deviceId):
@@ -30,8 +27,8 @@ def createDevice(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/topology/device?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/topology/device?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def createPhysical(vmanage, deviceId):
@@ -47,6 +44,6 @@ def createPhysical(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/topology/physical?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/topology/physical?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
