@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getDreAutoBypassStats(vmanage, ip, port, deviceId):
     """
     Get DRE auto-bypass statistics
@@ -16,8 +13,8 @@ def getDreAutoBypassStats(vmanage, ip, port, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/dre/auto-bypass-stats?appqoe-dre-auto-bypass-server-ip={ip}&appqoe-dre-auto-bypass-port={port}&deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/dre/auto-bypass-stats?appqoe-dre-auto-bypass-server-ip={ip}&appqoe-dre-auto-bypass-port={port}&deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getDreStats(vmanage, deviceId):
     """
@@ -32,8 +29,8 @@ def getDreStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/dre/dre-stats?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/dre/dre-stats?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getDreStatus(vmanage, deviceId):
     """
@@ -48,8 +45,8 @@ def getDreStatus(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/dre/dre-status?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/dre/dre-status?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getDrePeerStats(vmanage, ip, peerNo, deviceId):
     """
@@ -66,6 +63,6 @@ def getDrePeerStats(vmanage, ip, peerNo, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/dre/peer-stats?appqoe-dre-stats-peer-system-ip={ip}&appqoe-dre-stats-peer-peer-no={peerNo}&deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/dre/peer-stats?appqoe-dre-stats-peer-system-ip={ip}&appqoe-dre-stats-peer-peer-no={peerNo}&deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
