@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getInterfaceList(vmanage, deviceId):
     """
     Get PIM interface list from device
@@ -14,8 +11,8 @@ def getInterfaceList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/pim/interface?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/pim/interface?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getNeighborList(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getNeighborList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/pim/neighbor?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/pim/neighbor?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getRpMappingList(vmanage, deviceId):
     """
@@ -46,8 +43,8 @@ def getRpMappingList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/pim/rp-mapping?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/pim/rp-mapping?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStatsList(vmanage, deviceId):
     """
@@ -62,8 +59,8 @@ def getStatsList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/pim/statistics?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/pim/statistics?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getPPPInterfaceList(vmanage, deviceId):
     """
@@ -78,6 +75,6 @@ def getPPPInterfaceList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/ppp/interface?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/ppp/interface?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
