@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getActiveTCPFlows(vmanage, deviceId):
     """
     Get TCP optimized active flows from device (Real Time)
@@ -14,8 +11,8 @@ def getActiveTCPFlows(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tcpopt/activeflows?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/tcpopt/activeflows?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getExpiredTCPFlows(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getExpiredTCPFlows(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tcpopt/expiredflows?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/tcpopt/expiredflows?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getTCPSummary(vmanage, deviceId):
     """
@@ -46,6 +43,6 @@ def getTCPSummary(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tcpopt/summary?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/tcpopt/summary?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
