@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getVPNInstances(vmanage, deviceId):
     """
     Get VPN instance list from device (Real Time)
@@ -14,6 +11,6 @@ def getVPNInstances(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/vpn?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/vpn?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
